Package: sampling
Version: 2.11
Date: 2025-07-10
Title: Survey Sampling
Authors@R: c(person(given = "Yves",
                      family = "Tillé",
                      role = "aut",
                      email = "yves.tille@unine.ch"),
               person(given = "Alina",
                      family = "Matei",
                      role = c("aut", "cre"),
                      email = "alina.matei@unine.ch"))
Description: Functions to draw random samples using different sampling schemes are available. Functions are also provided to obtain (generalized) calibration weights, different estimators, as well some variance estimators.  
Imports: MASS, lpSolve, utils
Depends: R (>= 3.5.0)
License: GPL (>= 2)
Encoding: UTF-8
NeedsCompilation: yes
Packaged: 2025-07-10 14:52:52 UTC; sematei
Author: Yves Tillé [aut],
  Alina Matei [aut, cre]
Maintainer: Alina Matei <alina.matei@unine.ch>
Repository: CRAN
Date/Publication: 2025-07-10 17:20:02 UTC
