\name{sampling-internal}
\alias{.as_int}
\title{Internal sampling Functions}
\description{
 Internal sampling function
}
\usage{
.as_int(x)
}
\details{
These are not to be called by the user.
}
\keyword{internal}
